==> vradi-entities-0.3.1-sources.jar: com/jurismarches/vradi/entities/WebHarvestStreamAbstract.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.BusinessEntity;
import org.nuiton.wikitty.BusinessEntityWikitty;
import org.nuiton.wikitty.Wikitty;
import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyTreeNode;
import org.nuiton.wikitty.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.WikittyTreeNodeImpl;
import org.nuiton.wikitty.WikittyUser;
import org.nuiton.wikitty.WikittyUserAbstract;
import org.nuiton.wikitty.WikittyUserImpl;
import org.nuiton.wikitty.WikittyUtil;


public  abstract class WebHarvestStreamAbstract extends BusinessEntityWikitty implements WebHarvestStream, XmlStream {

    public static final List<WikittyExtension> extensions;
    public static final WikittyExtension extensionWebHarvestStream;
    /**
     * getScriptUrl :
     * @return String 
     */

    @Override
    public String getScriptUrl() {
        String value = WebHarvestStreamHelper.getScriptUrl(getWikitty());
        return value;
}

    /**
     * setScriptUrl :
     * @param scriptUrl 
     */

    @Override
    public void setScriptUrl(String scriptUrl) {
        String oldValue = getScriptUrl();
        WebHarvestStreamHelper.setScriptUrl(getWikitty(), scriptUrl);
        getPropertyChangeSupport().firePropertyChange(WebHarvestStream.FIELD_WEBHARVESTSTREAM_SCRIPTURL, oldValue, getScriptUrl());
}

    /**
     * getUrl :
     * @return String 
     */

    public String getUrl() {
        String value = XmlStreamHelper.getUrl(getWikitty());
        return value;
}

    /**
     * setUrl :
     * @param url 
     */

    public void setUrl(String url) {
        String oldValue = getUrl();
        XmlStreamHelper.setUrl(getWikitty(), url);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_URL, oldValue, getUrl());
}

    /**
     * getName :
     * @return String 
     */

    public String getName() {
        String value = XmlStreamHelper.getName(getWikitty());
        return value;
}

    /**
     * setName :
     * @param name 
     */

    public void setName(String name) {
        String oldValue = getName();
        XmlStreamHelper.setName(getWikitty(), name);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_NAME, oldValue, getName());
}

    /**
     * getFormTypeName :
     * @return String 
     */

    public String getFormTypeName() {
        String value = XmlStreamHelper.getFormTypeName(getWikitty());
        return value;
}

    /**
     * setFormTypeName :
     * @param formTypeName 
     */

    public void setFormTypeName(String formTypeName) {
        String oldValue = getFormTypeName();
        XmlStreamHelper.setFormTypeName(getWikitty(), formTypeName);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_FORMTYPENAME, oldValue, getFormTypeName());
}

    /**
     * getImportTime :
     * @return String 
     */

    public String getImportTime() {
        String value = XmlStreamHelper.getImportTime(getWikitty());
        return value;
}

    /**
     * setImportTime :
     * @param importTime 
     */

    public void setImportTime(String importTime) {
        String oldValue = getImportTime();
        XmlStreamHelper.setImportTime(getWikitty(), importTime);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_IMPORTTIME, oldValue, getImportTime());
}

    /**
     * getXmlFieldBinding :
     * @return Set<String> 
     */

    public Set<String> getXmlFieldBinding() {
        Set<String> result = XmlStreamHelper.getXmlFieldBinding(getWikitty());
        return result;
}

    /**
     * addXmlFieldBinding :
     * @param element 
     */

    public void addXmlFieldBinding(String element) {
        XmlStreamHelper.addXmlFieldBinding(getWikitty(), element);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_XMLFIELDBINDING, null, getXmlFieldBinding());
}

    /**
     * removeXmlFieldBinding :
     * @param element 
     */

    public void removeXmlFieldBinding(String element) {
        XmlStreamHelper.removeXmlFieldBinding(getWikitty(), element);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_XMLFIELDBINDING, null, getXmlFieldBinding());
}

    /**
     * clearXmlFieldBinding :
     */

    public void clearXmlFieldBinding() {
        XmlStreamHelper.clearXmlFieldBinding(getWikitty());
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_XMLFIELDBINDING, null, getXmlFieldBinding());
}

    /**
     * WebHarvestStreamAbstract :
     */

    public WebHarvestStreamAbstract() {
        super();
}

    /**
     * WebHarvestStreamAbstract :
     * @param wikitty 
     */

    public WebHarvestStreamAbstract(Wikitty wikitty) {
        super(wikitty);
}

    /**
     * WebHarvestStreamAbstract :
     * @param businessEntityWikitty 
     */

    public WebHarvestStreamAbstract(BusinessEntityWikitty businessEntityWikitty) {
        super(businessEntityWikitty.getWikitty());
}

    /**
     * getStaticExtensions :
     * @return Collection<WikittyExtension> 
     */

    @Override
    public Collection<WikittyExtension> getStaticExtensions() {
        return extensions;
}

static {
    
        extensionWebHarvestStream =
                new WikittyExtension(EXT_WEBHARVESTSTREAM,
                                     "1.0", // version
                                     XmlStream.EXT_XMLSTREAM,
                                     WikittyUtil.buildFieldMapExtension( // building field map
                                             "String scriptUrl unique=true"));

        // init extensions
        List<WikittyExtension> exts = new ArrayList<WikittyExtension>();

        exts.addAll(XmlStreamAbstract.extensions); 
        // current after requires ones

        exts.add(extensionWebHarvestStream);
        extensions = Collections.unmodifiableList(exts);

    }
    /**
     * toString :
     * @return String 
     */

    @Override
    public String toString() {
        return getWikitty().toString();
}


} //WebHarvestStreamAbstract

==> vradi-entities-0.5.1-sources.jar: com/jurismarches/vradi/entities/WebHarvestStreamAbstract.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;


public  abstract class WebHarvestStreamAbstract extends BusinessEntityImpl implements WebHarvestStream {

    public static final List<WikittyExtension> extensions;
    public static final WikittyExtension extensionWebHarvestStream;
    /**
     * getScriptUrl :
     * @return String 
     */

    @Override
    public String getScriptUrl() {
        String value = WebHarvestStreamHelper.getScriptUrl(getWikitty());
        return value;
}

    /**
     * setScriptUrl :
     * @param scriptUrl 
     */

    @Override
    public void setScriptUrl(String scriptUrl) {
        String oldValue = getScriptUrl();
        WebHarvestStreamHelper.setScriptUrl(getWikitty(), scriptUrl);
        getPropertyChangeSupport().firePropertyChange(WebHarvestStream.FIELD_WEBHARVESTSTREAM_SCRIPTURL, oldValue, getScriptUrl());
}

    /**
     * getUrl :
     * @return String 
     */

    public String getUrl() {
        String value = XmlStreamHelper.getUrl(getWikitty());
        return value;
}

    /**
     * setUrl :
     * @param url 
     */

    public void setUrl(String url) {
        String oldValue = getUrl();
        XmlStreamHelper.setUrl(getWikitty(), url);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_URL, oldValue, getUrl());
}

    /**
     * getName :
     * @return String 
     */

    public String getName() {
        String value = XmlStreamHelper.getName(getWikitty());
        return value;
}

    /**
     * setName :
     * @param name 
     */

    public void setName(String name) {
        String oldValue = getName();
        XmlStreamHelper.setName(getWikitty(), name);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_NAME, oldValue, getName());
}

    /**
     * getFormTypeName :
     * @return String 
     */

    public String getFormTypeName() {
        String value = XmlStreamHelper.getFormTypeName(getWikitty());
        return value;
}

    /**
     * setFormTypeName :
     * @param formTypeName 
     */

    public void setFormTypeName(String formTypeName) {
        String oldValue = getFormTypeName();
        XmlStreamHelper.setFormTypeName(getWikitty(), formTypeName);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_FORMTYPENAME, oldValue, getFormTypeName());
}

    /**
     * getImportTime :
     * @return String 
     */

    public String getImportTime() {
        String value = XmlStreamHelper.getImportTime(getWikitty());
        return value;
}

    /**
     * setImportTime :
     * @param importTime 
     */

    public void setImportTime(String importTime) {
        String oldValue = getImportTime();
        XmlStreamHelper.setImportTime(getWikitty(), importTime);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_IMPORTTIME, oldValue, getImportTime());
}

    /**
     * getXmlFieldBinding :
     * @return Set<String> 
     */

    public Set<String> getXmlFieldBinding() {
        Set<String> result = XmlStreamHelper.getXmlFieldBinding(getWikitty());
        return result;
}

    /**
     * setXmlFieldBinding :
     * @param xmlFieldBinding 
     */

    public void setXmlFieldBinding(Set<String> xmlFieldBinding) {
        Set<String> oldValue = getXmlFieldBinding();
        XmlStreamHelper.setXmlFieldBinding(getWikitty(), xmlFieldBinding);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_XMLFIELDBINDING, oldValue, getXmlFieldBinding());
}

    /**
     * addAllXmlFieldBinding :
     * @param xmlFieldBinding 
     */

    public void addAllXmlFieldBinding(Set<String> xmlFieldBinding) {
        Set<String> oldValue = getXmlFieldBinding();
        XmlStreamHelper.addAllXmlFieldBinding(getWikitty(), xmlFieldBinding);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_XMLFIELDBINDING, oldValue, getXmlFieldBinding());
}

    /**
     * addXmlFieldBinding :
     * @param element 
     */

    public void addXmlFieldBinding(String element) {
        XmlStreamHelper.addXmlFieldBinding(getWikitty(), element);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_XMLFIELDBINDING, null, getXmlFieldBinding());
}

    /**
     * removeXmlFieldBinding :
     * @param element 
     */

    public void removeXmlFieldBinding(String element) {
        XmlStreamHelper.removeXmlFieldBinding(getWikitty(), element);
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_XMLFIELDBINDING, null, getXmlFieldBinding());
}

    /**
     * clearXmlFieldBinding :
     */

    public void clearXmlFieldBinding() {
        XmlStreamHelper.clearXmlFieldBinding(getWikitty());
        getPropertyChangeSupport().firePropertyChange(XmlStream.FIELD_XMLSTREAM_XMLFIELDBINDING, null, getXmlFieldBinding());
}

    /**
     * WebHarvestStreamAbstract :
     */

    public WebHarvestStreamAbstract() {
        super();
}

    /**
     * WebHarvestStreamAbstract :
     * @param wikitty 
     */

    public WebHarvestStreamAbstract(Wikitty wikitty) {
        super(wikitty);
}

    /**
     * WebHarvestStreamAbstract :
     * @param businessEntityImpl 
     */

    public WebHarvestStreamAbstract(BusinessEntityImpl businessEntityImpl) {
        super(businessEntityImpl.getWikitty());
}

    /**
     * getStaticExtensions :
     * @return Collection<WikittyExtension> 
     */

    @Override
    public Collection<WikittyExtension> getStaticExtensions() {
        return extensions;
}

static {
    
        extensionWebHarvestStream =
                new WikittyExtension(EXT_WEBHARVESTSTREAM,
                                     "1.0", // version
                                     XmlStream.EXT_XMLSTREAM,
                                     WikittyUtil.buildFieldMapExtension( // building field map
                                             "String scriptUrl unique=\"true\""));

        // init extensions
        List<WikittyExtension> exts = new ArrayList<WikittyExtension>();

        exts.addAll(XmlStreamAbstract.extensions); 
        // current after requires ones

        exts.add(extensionWebHarvestStream);
        extensions = Collections.unmodifiableList(exts);

    }
    /**
     * toString :
     * @return String 
     */

    @Override
    public String toString() {
        return getWikitty().toString();
}


} //WebHarvestStreamAbstract
